@@ -14,6 +14,8 @@ from .win_animated_button import NWinAnimatedButton
 from .checkbox import NCheckBox
 from .checkbox_animated import NAnimatedCheckBox
 from .simple_line_edit import NSimpleLineEdit
+from .horizontal_slider import NHorizontalSlider
+from .vertical_slider import NVerticalSlider
 
 
-__version__ = '0.0.2'
+__version__ = '0.0.6'
